@@ -511,15 +511,15 @@ def open_data(x=[], checks=False, **kwargs):
                                 )
                                 if "Open failed" in str(out.stderr):
                                     raise ValueError(f"{x} is not compatible with CDO!")
-                        else:
-                            out = subprocess.run(
-                                "cdo sinfo " + x,
-                                shell=True,
-                                stdout=subprocess.PIPE,
-                                stderr=subprocess.PIPE,
-                            )
-                            if "Open failed" in str(out.stderr):
-                                raise ValueError(f"{x} is not compatible with CDO!")
+                        #else:
+                        #    out = subprocess.run(
+                        #        "cdo sinfo " + x,
+                        #        shell=True,
+                        #        stdout=subprocess.PIPE,
+                        #        stderr=subprocess.PIPE,
+                        #    )
+                        #    if "Open failed" in str(out.stderr):
+                        #        raise ValueError(f"{x} is not compatible with CDO!")
 
             else:
                 raise ValueError("Data set " + x + " does not exist!")
@@ -1242,6 +1242,8 @@ class DataSet(object):
 
     from nctoolkit.crop import crop
 
+    from nctoolkit.distgrid import distribute
+
     from nctoolkit.drop import drop
 
     from nctoolkit.ensembles import ensemble_mean
@@ -1271,6 +1273,7 @@ class DataSet(object):
 
     from nctoolkit.masking import mask_box
 
+    from nctoolkit.mergers import collect
     from nctoolkit.mergers import merge_time
     from nctoolkit.mergers import merge
 
@@ -1365,7 +1368,4 @@ class DataSet(object):
 
     # deprecated stuff
 
-    from nctoolkit.deprecated import mutate
-    from nctoolkit.deprecated import transmute
-
     from nctoolkit.compare import compare_all
