@@ -226,23 +226,49 @@ def assign(self, drop=False, **kwargs):
 
         if readline.get_current_history_length() > 0:
             interactive = True
-
-    if interactive:
-        import readline
-
-        start = [
-            str(readline.get_history_item(i + 1))
-            for i in range(readline.get_current_history_length())
-        ][-1]
-    else:
+    try:
         start = lambdas
         try:
-            start = inspect.getsourcelines(start)[0][0].replace("\n", "").strip()
+            all_str = list(inspect.getsourcelines(start))[0]
+            all_str = "".join(all_str)
+            start = all_str.replace("'", "").replace("\\n", "")[1:-1].replace("  ", " ")
+            start = start.replace("\n", "")
         except:
             start = dill.source.getsource(start).replace("\n", "").strip()
+    except:
+
+        if interactive:
+            import readline
+
+            start = [
+                str(readline.get_history_item(i + 1))
+                for i in range(readline.get_current_history_length())
+            ]
+            i = 0
+            for ss in start:
+                if ".assign(" in ss:
+                    ind = i
+                i+=1
+
+            all_str = start[ind:len(start)]
+            all_str = "".join(all_str)
+            start = all_str.replace("'", "").replace("\\n", "").replace("  ", " ")
+        else:
+            start = lambdas
+            try:
+                all_str = list(inspect.getsourcelines(start))[0]
+                all_str = "".join(all_str)
+                start = all_str.replace("'", "").replace("\\n", "")[1:-1].replace("  ", " ")
+
+            except:
+                start = dill.source.getsource(start).replace("\n", "").strip()
+
 
     # we now need to figure out if what we have is one line
 
+    if ";" in start:
+        raise ValueError("You cannot split assign calls using ;")
+
     if ".assign(" not in start:
         raise ValueError("Please write assign methods as single line!")
 
@@ -252,6 +278,7 @@ def assign(self, drop=False, **kwargs):
         raise ValueError("Please write assign methods as single line!")
 
     start = start[start.find("(") + 1 : -1]
+    start = re.sub("\s\s+" , " ", start)
 
     pattern1 = re.compile("drop\s*=\s*(True|False)")
     y = pattern1.search(start)
