@@ -32,6 +32,9 @@ def cell_area(self, join=True):
 
     """
 
+    if len(self) == 0:
+        raise ValueError("Failure due to empty dataset!")
+
     if isinstance(join, bool) is False:
         raise TypeError("join is not boolean")
 
@@ -48,7 +51,7 @@ def cell_area(self, join=True):
 
         for ff in self:
 
-            if cdo_version() in ["1.9.3", "1.9.4", "1.9.5", "1.9.6"]:
+            if cdo_version() in ["1.9.4", "1.9.5", "1.9.6"]:
 
                 # in cdo < 1.9.6 chaining doesn't work with merge
 
