@@ -1,8 +1,7 @@
 from nctoolkit.runthis import run_this
 from nctoolkit.session import session_info
 
-
-def format(self, ext = None):
+def format(self, ext=None):
     """
     Zip the dataset
     This will compress the files within the dataset. This works lazily.
@@ -10,11 +9,11 @@ def format(self, ext = None):
     -------------
     ext: str
         New format. Must be one of "nc", "nc1", "nc2",  "nc4" and "nc5" .
-        NetCDF = nc1
-        NetCDF version 2 (64-bit offset) = nc2/nc
-        NetCDF4 (HDF5) = nc4
-        NetCDF4-classi = nc4c
-        NetCDF version 5 (64-bit data) = nc5
+        netCDF = nc1
+        netCDF version 2 (64-bit offset) = nc2/nc
+        netCDF4 (HDF5) = nc4
+        netCDF4-classi = nc4c
+        netCDF version 5 (64-bit data) = nc5
     """
 
     if ext is None:
@@ -26,12 +25,8 @@ def format(self, ext = None):
     if ext not in ["nc", "nc1", "nc2", "nc4", "nc4c", "nc5"]:
         raise ValueError(f"{ext} is not a valid format!")
 
-
     self._format = ext
 
     if session_info["lazy"] == False:
         self._execute = False
         self.run()
-
-
-
