@@ -142,9 +142,6 @@ def merge(self, match=["year", "month", "day"]):
     if session_info["lazy"]:
         self._merged = True
 
-    if cdo_version() in ["1.9.3"]:
-        self.run()
-
 
 def merge_time(self):
     """
@@ -166,5 +163,23 @@ def merge_time(self):
     if session_info["lazy"]:
         self._merged = True
 
-    if cdo_version() in ["1.9.3"]:
-        self.run()
+
+
+
+def collect(self):
+    """
+    Collect a dataset that has been split using distribute
+    """
+
+    self.run()
+
+    if len(self) == 1:
+        warnings.warn(message="There is only file in the dataset. No need to merge!")
+        return None
+
+    cdo_command = "cdo -collgrid"
+
+    run_this(cdo_command, self, output="one")
+
+    self.run()
+
