@@ -17,6 +17,8 @@ from nctoolkit.session import (
 )
 from nctoolkit.temp_file import temp_file
 
+from nctoolkit.utils import cdo_version
+
 
 def file_size(file_path):
     """
@@ -425,6 +427,9 @@ def run_cdo(command, target, out_file=None, overwrite=False):
 
 def run_this(os_command, self, output="one", out_file=None):
 
+    if len(self) == 0:
+        raise ValueError("Failure do to empty dataset!")
+
     self._ncommands += 1
 
     cores = session_info["cores"]
@@ -432,6 +437,16 @@ def run_this(os_command, self, output="one", out_file=None):
     if len(self) == 1:
         output = "ensemble"
 
+    if (len(self._hold_history) != len(self.history)):
+        if self._merged == False and len(self.history) > 0 and output == "one":
+
+            if cdo_version() in ["9.9.9"]:
+                the_command = self.history[-1].replace("cdo", "") + " "
+                the_command = the_command.replace(" -L ", " ").strip()
+                if "apply," not in the_command:
+                    self.history[-1] = f'-apply,"{the_command}"'
+
+
     if self._execute is False:
         if len(self._hold_history) == len(self.history):
             self.history.append(os_command)
@@ -554,6 +569,7 @@ def run_this(os_command, self, output="one", out_file=None):
 
             file_list = self.current
 
+
             if len(self.history) > len(self._hold_history):
                 os_command = f'{os_command} {self.history[-1].replace("cdo ", " ")}'
                 os_command = os_command.replace("  ", " ")
@@ -578,9 +594,10 @@ def run_this(os_command, self, output="one", out_file=None):
                 target = out_file
 
             os_command = (
-                os_command + " " + str_flatten(self.current, " ") + " " + target
+                os_command + " [ " + str_flatten(self.current, " ") + " ] " + target
             )
 
+
             zip_copy = False
             if self._zip and self._ncommands == 1:
                 zip_copy = True
