@@ -21,7 +21,7 @@ def set_date(self, year=None, month=None, day=None, base_year=1900):
     day : int
         The day
     base_year : int
-        The base year for time creation in the netcdf. Defaults to 1900.
+        The base year for time creation in the netCDF. Defaults to 1900.
     """
 
     if year is None:
@@ -42,8 +42,10 @@ def set_date(self, year=None, month=None, day=None, base_year=1900):
     if type(day) is not int:
         raise TypeError("day supplied is not an int")
 
-    cdo_command = f"cdo -setreftime,{str(base_year)}-01-01 "\
-                  f"-setdate,{str(year)}-{str(month)}-{str(day)}"
+    cdo_command = (
+        f"cdo -setreftime,{str(base_year)}-01-01 "
+        f"-setdate,{str(year)}-{str(month)}-{str(day)}"
+    )
 
     run_this(cdo_command, self, output="ensemble")
 
@@ -155,7 +157,6 @@ def set_longnames(self, name_dict=None):
     self.history += new_commands
     self._hold_history = copy.deepcopy(self.history)
 
-
     self.current = new_files
 
     for ff in new_files:
