@@ -21,7 +21,7 @@ def bottom(self):
 
     If you wanted to extract the bottom vertical level of a dataset, do the following:
 
-    >>> data.bottom()
+    >>> ds.bottom()
 
     This method is most useful for things like oceanic model data, where the bottom cell corresponds to the bottom of the ocean.
 
@@ -61,7 +61,7 @@ def surface(self):
 
     If you wanted to extract the top vertical level of a dataset, do the following:
 
-    >>> data.surface()
+    >>> ds.surface()
 
     This method is most useful for things like oceanic data, where this method will extract the sea surface.
     """
@@ -86,7 +86,7 @@ def vertical_interp(self, levels=None):
 
     If you wanted to vertically interpolate a dataset to 5 and 10 metres, you would do the following:
 
-    >>> data.vertical_interp([5,10])
+    >>> ds.vertical_interp([5,10])
 
     This method is most useful for things like oceanic data, where you need to interpolate to certain depth levels.
     It will require that vertical levels are the same in every grid cell.
@@ -127,7 +127,7 @@ def vertical_mean(self):
 
     If you wanted to vertical mean of every variable in a dataset, you would do this:
 
-    >>> data.vertical_mean()
+    >>> ds.vertical_mean()
 
     This method will calculate the vertical mean weighted by the thickness of each cell. Note that
     if cell thickness cannot be derived it will just average the values in each vertical cell.
@@ -147,7 +147,7 @@ def vertical_min(self):
 
     If you wanted to vertical minimum of every variable in a dataset, you would do this:
 
-    >>> data.vertical_min()
+    >>> ds.vertical_min()
 
     """
     vertstat(self, stat="min")
@@ -163,7 +163,7 @@ def vertical_max(self):
 
     If you wanted to vertical maximum of every variable in a dataset, you would do this:
 
-    >>> data.vertical_max()
+    >>> ds.vertical_max()
 
     """
     vertstat(self, stat="max")
@@ -179,7 +179,7 @@ def vertical_range(self):
 
     If you wanted to range of values across all vertical levels of every variable in a dataset, you would do this:
 
-    >>> data.vertical_range()
+    >>> ds.vertical_range()
 
     """
     vertstat(self, stat="range")
@@ -195,7 +195,7 @@ def vertical_sum(self):
 
     If you wanted to sum of values across all vertical levels of every variable in a dataset, you would do this:
 
-    >>> data.vertical_sum()
+    >>> ds.vertical_sum()
 
     """
     vertstat(self, stat="sum")
@@ -211,7 +211,7 @@ def vertical_cumsum(self):
 
     If you wanted to calculate the cumulative sum of values across all vertical levels of every variable in a dataset, you would do this:
 
-    >>> data.vertical_sum()
+    >>> ds.vertical_sum()
 
     The cumulative sum will be calculated from the first to the last vertical level. For example, in oceanic data it would start at the sea surface.
     """
@@ -228,7 +228,7 @@ def invert_levels(self):
 
     If you wanted to invert the vertical levels, you would do this:
 
-    >>> data.invert_levels()
+    >>> ds.invert_levels()
 
     """
     cdo_command = "cdo -invertlev"
